import 'package:flutter/material.dart';
import 'package:store_ds/store.dart';
import 'package:validators/sanitizers.dart';
import 'package:validators/validators.dart';

final textdecor = InputDecoration(
    fillColor: Colors.white,
    border: OutlineInputBorder(
        borderRadius: BorderRadius.circular(25.0), borderSide: BorderSide()));

class Home extends StatefulWidget {
  const Home({
    Key key,
  }) : super(key: key);

  @override
  _HomeState createState() => _HomeState();
}

class _HomeState extends State<Home> {

  @override
  void initState() {
    useStore('form') ;
    super.initState();
    saveToStoreMultiple({
      'name': '', // textbox
      'price': 0, // textbox
      'category': 'fresh' // Dropdown
    });
  }

  Widget createTextBoxes({
    @required String labelText,
    @required String key,
    @required FormFieldValidator<String> validator,
    @required TextInputType keyboardType,
    @required InputDecoration decoration,
  }) =>
      TextFormField(
        validator: validator,
        onChanged: (value) => saveToStore(key, value),
        decoration: decoration.copyWith(labelText: labelText),
        onSaved: (value) => saveToStore(key, value),
        keyboardType: keyboardType,
      );

  final formkey = GlobalKey<FormState>();

  @override
  Widget build(BuildContext context) {
    
    logCompleteStore();


    return Form(
      key: formkey,
      child: Padding(
        padding: const EdgeInsets.all(20.0),
        child: Column(
          children: <Widget>[
            createTextBoxes(
              labelText: 'Name',
              decoration: textdecor,
              key: 'name',
              validator: (v) {
                if (!isAlpha(v)) return 'Invalid Value';
                return null;
              },
              keyboardType: TextInputType.text,
            ),
            SizedBox(
              height: 10,
            ),
            createTextBoxes(
                labelText: 'Price',
                decoration: textdecor,
                key: 'price',
                validator: (v) {
                  if (toDouble(v).isNaN) return 'Invalid Value';
                  return null;
                },
                keyboardType: TextInputType.number),
            SizedBox(
              height: 10,
            ),
            DropdownButtonFormField<String>(
              items: <String>['canned', 'fresh', 'packed'].map((String value) {
                return DropdownMenuItem<String>(
                  value: value,
                  child: Text(value),
                );
              }).toList(),
              onChanged: (value) {
                saveToStore('category', value);
              },
              value: getFromStore('category'),
              onSaved: (value) => saveToStore('category', value),
            ),
            RaisedButton(
              child: Text('Save'),
              onPressed: () {
                formkey.currentState.save();
                setState(() {});

                // if (formkey.currentState.validate()) {}
              },
            ),
            Text(serveStore().toString())
          ],
        ),
      ),
    );
  }
}